@@ -14,7 +14,7 @@ Or in Python:
     setup_claude_integration()
 """
 
-__version__ = "0.8.5"
+__version__ = "0.8.31"
 
 # Plugin integration
 from .ai_integration.plugins import AIDesignBridge
@@ -60,13 +60,6 @@ from .core.netlist_exporter import NetlistExporter
 # Reference manager and netlist exporters
 from .core.reference_manager import ReferenceManager
 
-# Rust-accelerated component creation helpers
-from .core.rust_components import (
-    create_rust_capacitor,
-    create_rust_resistor,
-    get_rust_component_status,
-)
-
 # Removed unused interface abstractions and unified integration
 
 
@@ -86,13 +79,7 @@ def setup_claude_integration():
 
 
 # KiCad API imports
-from .kicad.core.types import (
-    Junction,
-    Label,
-    Schematic,
-    SchematicSymbol,
-    Wire,
-)
+from .kicad.core.types import Junction, Label, Schematic, SchematicSymbol, Wire
 
 __all__ = [
     # Core
@@ -128,10 +115,6 @@ __all__ = [
     "ReferenceManager",
     "NetlistExporter",
     "EnhancedNetlistExporter",
-    # Rust-accelerated component creation
-    "create_rust_resistor",
-    "create_rust_capacitor",
-    "get_rust_component_status",
     # KiCad integration and validation
     "validate_kicad_installation",
     "require_kicad",
